pyjabber.stream package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyjabber.stream.server

Submodules
----------

pyjabber.stream.JID module
--------------------------

.. automodule:: pyjabber.stream.JID
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.stream.QueueMessage module
-----------------------------------

.. automodule:: pyjabber.stream.QueueMessage
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.stream.StanzaHandler module
------------------------------------

.. automodule:: pyjabber.stream.StanzaHandler
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.stream.Stream module
-----------------------------

.. automodule:: pyjabber.stream.Stream
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.stream.StreamHandler module
------------------------------------

.. automodule:: pyjabber.stream.StreamHandler
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.stream
   :members:
   :undoc-members:
   :show-inheritance:
